@@ -3,6 +3,7 @@ from pathlib import Path
 from typing import Any, List, Optional, Tuple, Union
 import httpx
 from fasttext import FastText, load_model  # type: ignore
+from numpy import array
 from numpy.typing import NDArray
 
 
@@ -85,14 +86,18 @@ def beautify_one(
 
 
 def beautify_many(
-    responses: Tuple[str, NDArray], threshold: Optional[float] = 0.5
-) -> List[Language]:
+    responses: Tuple[str, NDArray],
+    threshold: Optional[float] = 0.5,
+    only_language: Optional[bool] = False,
+    to_array: Optional[bool] = False,
+) -> Union[List[Union[str, Language]], NDArray]:
 
     # ([['__label__da'], ['__label__en']],
     # [array([0.99840873], dtype=float32), array([0.9827167], dtype=float32)])
 
     languages, scores = responses
     results = []
+
     for lang, score_ in zip(languages, scores):
         score = score_.squeeze().item()
 
@@ -102,6 +107,13 @@ def beautify_many(
         else:
             results.append(Language(name=lang[0].replace("__label__", ""), score=score))
 
+    # smelly code
+    if only_language:
+        results = [response.name for response in results]  # type: ignore
+
+    if to_array:
+        results = array(results)
+
     return results
 
 
