@@ -1,4 +1,5 @@
 from typing import List, Optional, Union
+from numpy.typing import NDArray
 from luga.artifacts import fmodel, beautify_one, beautify_many, Language
 
 
@@ -14,16 +15,19 @@ def languages(
     texts: List[str],
     threshold: Optional[float] = 0.5,
     only_language: Optional[bool] = False,
-) -> Union[List[str], List[Language]]:
+    to_array: Optional[bool] = False,
+) -> Union[List[Union[str, Language]], NDArray]:
 
     assert isinstance(
         texts, List
     ), f"text ought be type List[str], we got {type(texts)}"
 
     responses_ = fmodel.predict(texts)
-    responses = beautify_many(responses=responses_, threshold=threshold)
-
-    if only_language:
-        return [response.name for response in responses]
+    responses = beautify_many(
+        responses=responses_,
+        threshold=threshold,
+        only_language=only_language,
+        to_array=to_array,
+    )
 
     return responses
